@@ -51,12 +51,25 @@ class DingDingPlugin(NotificationPlugin):
         send_url = DingTalk_API.format(token=access_token)
         title = "New alert from {}".format(event.project.slug)
         event_url = "{0}events/{1}/".format(group.get_absolute_url(), event.id)
+        url_arr = event_url.split('/')
+        print(url_arr)
+        issue_id = url_arr[url_arr.index('issues') + 1]
+        print(issue_id)
+
+        issue_data = requests.get(
+            url="http://web-middle.ruibogyl.work/sentry/findIssueTargetUrl",
+            headers={"Content-Type": "application/json"},
+            data=json.dumps({
+                "id": issue_id
+            })).json()
+
+        print(issue_data)
 
         data = {
             "msgtype": "markdown",
             "markdown": {
                 "title": title,
-                "text": u"#### {title} \n > {message} [href]({url})".format(
+                "text": u"#### test {title} \n > {message} [href]({url})".format(
                     title=title,
                     message=event.message,
                     url=u"{}events/{}/".format(group.get_absolute_url(), event.id),
